==> ejc-guarantee-impl-3.0.0-20230413.000258-11-sources.jar: com/ejianc/business/guarantee/relieve/bean/ContractRelieveEntity.java <==
package com.ejianc.business.guarantee.relieve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 担保合同解保
 * 
 * @author generator
 * 
 */
 @TableName("ejc_guarantee_contract_relieve")
public class ContractRelieveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="relieve_remark")
    private String relieveRemark; // 备注
    @TableField(value="premium_mny")
    private BigDecimal premiumMny; // 保费金额
    @TableField(value="premium_tax_mny")
    private BigDecimal premiumTaxMny; // 保费金额(含税)
    @TableField(value="contract_id")
    private Long contractId; // 担保合同id
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRelieveRemark() {
        return relieveRemark;
    }

    public void setRelieveRemark(String relieveRemark) {
        this.relieveRemark = relieveRemark;
    }

    public BigDecimal getPremiumMny() {
        return premiumMny;
    }

    public void setPremiumMny(BigDecimal premiumMny) {
        this.premiumMny = premiumMny;
    }
    public BigDecimal getPremiumTaxMny() {
        return premiumTaxMny;
    }

    public void setPremiumTaxMny(BigDecimal premiumTaxMny) {
        this.premiumTaxMny = premiumTaxMny;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    
}

==> ejc-guarantee-impl-3.0.0-20230418.040435-14-sources.jar: com/ejianc/business/guarantee/relieve/bean/ContractRelieveEntity.java <==
package com.ejianc.business.guarantee.relieve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 担保合同解保
 * 
 * @author generator
 * 
 */
 @TableName("ejc_guarantee_contract_relieve")
public class ContractRelieveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="relieve_remark")
    private String relieveRemark; // 备注
    @TableField(value="premium_mny")
    private BigDecimal premiumMny; // 保费金额
    @TableField(value="premium_tax_mny")
    private BigDecimal premiumTaxMny; // 保费金额(含税)
    @TableField(value="contract_id")
    private Long contractId; // 担保合同id
    @TableField(value = "relieve_date")
    private Date relieveDate;//解保日期
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRelieveRemark() {
        return relieveRemark;
    }

    public void setRelieveRemark(String relieveRemark) {
        this.relieveRemark = relieveRemark;
    }

    public BigDecimal getPremiumMny() {
        return premiumMny;
    }

    public void setPremiumMny(BigDecimal premiumMny) {
        this.premiumMny = premiumMny;
    }
    public BigDecimal getPremiumTaxMny() {
        return premiumTaxMny;
    }

    public void setPremiumTaxMny(BigDecimal premiumTaxMny) {
        this.premiumTaxMny = premiumTaxMny;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Date getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(Date relieveDate) {
        this.relieveDate = relieveDate;
    }
}
